@@ -1,5 +1,6 @@
 from simsity.error import NotInstalled
 from .pynn import PyNNDescentIndexer
+from .annoy import AnnoyIndexer
 from .common import Indexer
 
 
@@ -9,4 +10,4 @@ except ModuleNotFoundError:
     MinHashIndexer = NotInstalled("MinHashIndexer", "minhash")
 
 
-__all__ = ["PyNNDescentIndexer", "MinHashIndexer", "Indexer"]
+__all__ = ["PyNNDescentIndexer", "MinHashIndexer", "Indexer", "AnnoyIndexer"]
