@@ -1,3 +1,8 @@
+import json
+import pathlib
+from pathlib import Path
+from joblib import dump, load
+
 from pynndescent import NNDescent
 
 from simsity.indexer.common import Indexer
@@ -11,11 +16,11 @@ class PyNNDescentIndexer(Indexer):
         metric: The metric to use for the index.
         n_neighbors: The number of neighbors to use for the index.
         random_state: The random state to use for the index.
-        n_jobs: The number of parallel jobs to run for neighbors index construction. `None` means 1 while `-1` means all processors.
+        n_jobs: The number of parallel jobs to run for neighbors index construction.
     """
 
     def __init__(
-        self, metric="euclidean", n_neighbors=10, random_state=42, n_jobs=None
+        self, metric="euclidean", n_neighbors=10, random_state=42, n_jobs=1
     ) -> None:
         self.metric = metric
         self.n_neighbors = n_neighbors
@@ -51,3 +56,34 @@ class PyNNDescentIndexer(Indexer):
             raise RuntimeError("Index not yet built.")
         idx, dist = self.model.query(query, n_neighbors)
         return list(idx[0]), list(dist[0])
+
+    def save(self, path) -> None:
+        """
+        Save the indexer in a path.
+
+        Arguments:
+            path: string or pathlib.Path to folder.
+        """
+        # Save the index
+        dump(self, pathlib.Path(path) / "indexer.joblib")
+
+        # Save the metadata so that we have the parameters on load.
+        metadata_path = Path(path) / "metadata.json"
+        metadata = json.loads(metadata_path.read_text())
+        metadata["pynn"] = dict(
+            metric=self.metric,
+            n_neighbors=self.n_neighbors,
+            random_state=self.random_state,
+            n_jobs=self.n_jobs,
+        )
+        metadata_path.write_text(json.dumps(metadata))
+
+    @classmethod
+    def load(cls, path) -> "Indexer":
+        """
+        Load the indexer in a path.
+
+        Arguments:
+            path: string or pathlib.Path to folder.
+        """
+        return load(pathlib.Path(path) / "indexer.joblib")
